@@ -103,8 +103,8 @@ def get_theme(theme_name, invert_secondary=False):
                   'secondaryDarkColor',
                   'primaryTextColor',
                   'secondaryTextColor']:
-        os.environ[f'PYSIDEMATERIAL_{color.upper()}'] = theme[color]
-    os.environ['PYSIDEMATERIAL_THEME'] = theme_name
+        os.environ[f'QTMATERIAL_{color.upper()}'] = theme[color]
+    os.environ['QTMATERIAL_THEME'] = theme_name
 
     return theme
 
@@ -113,8 +113,10 @@ def get_theme(theme_name, invert_secondary=False):
 def add_fonts():
     """"""
     fonts_path = os.path.join(os.path.dirname(__file__), 'fonts')
-    for font in os.listdir(fonts_path):
-        QFontDatabase.addApplicationFont(os.path.join(fonts_path, font))
+
+    for font in ['roboto']:
+        for font in filter(lambda s: s.endswith('.ttf'), os.listdir(os.path.join(fonts_path, font))):
+            QFontDatabase.addApplicationFont(os.path.join(fonts_path, font))
 
 
 # ----------------------------------------------------------------------
@@ -255,11 +257,11 @@ class QtStyleTools:
         if not hasattr(self, 'colors'):
             return
 
-        theme = {color_: os.environ[f'PYSIDEMATERIAL_{color_.upper()}'] for color_ in self.colors}
+        theme = {color_: os.environ[f'QTMATERIAL_{color_.upper()}'] for color_ in self.colors}
 
-        if 'light' in os.environ['PYSIDEMATERIAL_THEME']:
+        if 'light' in os.environ['QTMATERIAL_THEME']:
             self.dock_theme.checkBox_ligh_theme.setChecked(True)
-        elif 'dark' in os.environ['PYSIDEMATERIAL_THEME']:
+        elif 'dark' in os.environ['QTMATERIAL_THEME']:
             self.dock_theme.checkBox_ligh_theme.setChecked(False)
 
         if self.dock_theme.checkBox_ligh_theme.isChecked():
@@ -336,7 +338,7 @@ class QtStyleTools:
                        'primaryTextColor',
                        'secondaryTextColor']
 
-        self.custom_colors = {v: os.environ[f'PYSIDEMATERIAL_{v.upper()}'] for v in self.colors}
+        self.custom_colors = {v: os.environ[f'QTMATERIAL_{v.upper()}'] for v in self.colors}
 
         if 'PySide2' in sys.modules or 'PySide6' in sys.modules:
             self.dock_theme = QUiLoader().load(os.path.join(os.path.dirname(__file__), 'dock_theme.ui'))
@@ -347,7 +349,7 @@ class QtStyleTools:
         self.dock_theme.setFloating(True)
 
         self.update_buttons()
-        self.dock_theme.checkBox_ligh_theme.clicked.connect(self.update_theme)
+        self.dock_theme.checkBox_ligh_theme.clicked.connect(lambda: self.update_theme(self.main))
 
         for color in self.colors:
             button = getattr(self.dock_theme, f'pushButton_{color}')
